Unit Testing
============

Examples and best practices for Unit Testing nameko services.

Simple Example
--------------

.. literalinclude:: unit_test.py

Advanced Example
----------------

.. literalinclude:: unit_with_provided_injection_test.py


Integration Testing
===================

Examples and best practices for Integration Testing nameko services.

Simple Example
--------------

.. literalinclude:: integration_test.py

Advanced Example
----------------

.. literalinclude:: large_integration_test.py


.. _conftest:

conftest.py
===========

.. literalinclude:: conftest.py